@@ -1,7 +1,7 @@
 // -*- c++ -*-
 #ifndef _GLIBMM_OBJECT_H
 #define _GLIBMM_OBJECT_H
-/* $Id: object.h,v 1.1.1.1 2003/01/07 16:58:50 murrayc Exp $ */
+/* $Id: object.h,v 1.3 2004/03/13 15:20:16 murrayc Exp $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
@@ -23,8 +23,6 @@
 #include <glibmm/objectbase.h>
 #include <glibmm/wrap.h>
 #include <glibmm/quark.h>
-#include <glibmm/signalproxy.h>
-#include <glibmm/propertyproxy.h>
 #include <glibmm/refptr.h>
 #include <glibmm/utility.h> /* Could be private, but that would be tedious. */
 #include <glibmm/value.h>
@@ -61,8 +59,9 @@ class GSigConnectionNode;
  * The comments in object.cc and objectbase.cc should explain in detail
  * how this works.
  */
-struct ConstructParams
+class ConstructParams
 {
+public:
   const Glib::Class&  glibmm_class;
   unsigned int        n_parameters;
   GParameter*         parameters;
@@ -71,9 +70,13 @@ struct ConstructParams
   ConstructParams(const Glib::Class& glibmm_class_, const char* first_property_name, ...);
   ~ConstructParams();
 
+  //This is only used by the C++ compiler (since g++ 3.4) to create temporary instances.
+  //Apparently the compiler will actually optimize away the use of this.
+  //See bug #132300.
+  ConstructParams(const ConstructParams& src);
+
 private:
-  // noncopyable
-  ConstructParams(const ConstructParams&);
+  // noncopyable 
   ConstructParams& operator=(const ConstructParams&);
 };
 
@@ -126,20 +129,6 @@ public:
   //T& get_data_typed(const QueryQuark& quark)
   //  { return *static_cast<T*>(get_data(quark)); }
 
-  /// You probably want to use a specific property_*() accessor method instead.
-  void set_property_value(const Glib::ustring& property_name, const Glib::ValueBase& value);
-
-  /// You probably want to use a specific property_*() accessor method instead.
-  void get_property_value(const Glib::ustring& property_name, Glib::ValueBase& value) const;
-
-  /// You probably want to use a specific property_*() accessor method instead.
-  template <class PropertyType>
-  void set_property(const Glib::ustring& property_name, const PropertyType& value);
-
-  /// You probably want to use a specific property_*() accessor method instead.
-  template <class PropertyType>
-  void get_property(const Glib::ustring& property_name, PropertyType& value) const;
-
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 
 private:
@@ -156,32 +145,6 @@ private:
   //virtual void set_manage();
 };
 
-
-#ifndef DOXYGEN_SHOULD_SKIP_THIS
-
-template <class PropertyType>
-void Object::set_property(const Glib::ustring& property_name, const PropertyType& value)
-{
-  Glib::Value<PropertyType> property_value;
-  property_value.init(Glib::Value<PropertyType>::value_type());
-
-  property_value.set(value);
-  this->set_property_value(property_name, property_value);
-}
-
-template <class PropertyType>
-void Object::get_property(const Glib::ustring& property_name, PropertyType& value) const
-{
-  Glib::Value<PropertyType> property_value;
-  property_value.init(Glib::Value<PropertyType>::value_type());
-
-  this->get_property_value(property_name, property_value);
-
-  value = property_value.get();
-}
-
-#endif /* DOXYGEN_SHOULD_SKIP_THIS */
-
 } // namespace Glib
 
 #endif /* _GLIBMM_OBJECT_H */
